Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2633)

Unified Diff: media/base/media_log_event.h

Issue 23702007: Render inband text tracks in the media pipeline (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: fix compile errors 11/21 #6 Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/media_log.cc ('k') | media/base/mock_demuxer_host.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/media_log_event.h
diff --git a/media/base/media_log_event.h b/media/base/media_log_event.h
index 811d1131a7a9489abda363e89162bf1bed271087..3052d415c121b6bc22c6b987bf9d4aa4d76a7b56 100644
--- a/media/base/media_log_event.h
+++ b/media/base/media_log_event.h
@@ -70,9 +70,10 @@ struct MediaLogEvent {
TOTAL_BYTES_SET,
NETWORK_ACTIVITY_SET,
// Audio/Video stream playback has ended.
AUDIO_ENDED,
VIDEO_ENDED,
+ TEXT_ENDED,
// The audio renderer has been disabled.
// params: none.
« no previous file with comments | « media/base/media_log.cc ('k') | media/base/mock_demuxer_host.h » ('j') | no next file with comments »
@@ -70,9 +70,10 @@ struct MediaLogEvent {
TOTAL_BYTES_SET,
NETWORK_ACTIVITY_SET,
- // Audio/Video stream playback has ended.
+ // Audio/Video/Text stream playback has ended.
AUDIO_ENDED,
VIDEO_ENDED,

Powered by Google App Engine
This is Rietveld 408576698